@@ -101,6 +101,7 @@ class Template(object):
                     bases = (base, )
                 else:
                     bases = (SimultanObject, ) + (base, )
+                    # bases = (base, ) + (SimultanObject, )
 
                 # if SimultanObject in base.__bases__:
                 #     bases = (base, )
@@ -199,9 +200,6 @@ class TemplateParser(object):
         """
         Class which handles templates. This class generates python objects from the SIMULTAN data model for templates.
 
-        :param args:
-        :param kwargs:
-
         @keyword templates: list of templates; if templates is None and template_filepath is defined,
         templates are automatically loaded
         @keyword template_filepath: filepath to the template (*.yml)
@@ -401,7 +399,7 @@ def add_properties(prop, type):
         return next((x.set_ValueCurrent(value) for x in self._wrapped_obj.ContainedParameters.Items if x.Name == prop), None)
 
     def delx(self):
-        pass
+        logger.warning('delete method not implemented')
 
     return property(getx, setx, delx, f"automatic created property")
 
